@@ -51,11 +51,11 @@ def create(config):
             "rtx2070s",
             "rtx2080ti",
             "rtx3090",
-            "k80",
             "p100",
             "t4",
             "v100",
             "a100",
+            "a6000",
         ],
         case_sensitive=False,
     ),
@@ -63,6 +63,14 @@ def create(config):
     show_default=True,
     help="GPU type.",
 )
+@click.option(
+    "--max-price",
+    "-mp",
+    type=click.FLOAT,
+    default=10.0,
+    show_default=True,
+    help="Max Price (per GPU).",
+)
 @click.option(
     "--data-dir",
     type=click.Path(exists=True, file_okay=False, resolve_path=True),
@@ -165,6 +173,7 @@ def notebook(
     disk_size,
     gpu_count,
     gpu_type,
+    max_price,
     data_dir,
     dataset,
     public_dataset,
@@ -189,6 +198,7 @@ def notebook(
     ]
 
     options = dict(
+        max_price=max_price,
         data=dict(datasets=datasets),
         environment=dict(
             type="CUSTOM" if custom_image else environment,
@@ -311,11 +321,11 @@ def notebook(
             "rtx2070s",
             "rtx2080ti",
             "rtx3090",
-            "k80",
             "p100",
             "t4",
             "v100",
             "a100",
+            "a6000",
         ],
         case_sensitive=False,
     ),
@@ -323,6 +333,14 @@ def notebook(
     show_default=True,
     help="GPU type.",
 )
+@click.option(
+    "--max-price",
+    "-mp",
+    type=click.FLOAT,
+    default=10.0,
+    show_default=True,
+    help="Max Price (per GPU).",
+)
 @click.option(
     "--data-dir",
     type=click.Path(exists=True, file_okay=False, resolve_path=True),
@@ -448,6 +466,7 @@ def training(
     disk_size,
     gpu_count,
     gpu_type,
+    max_price,
     data_dir,
     dataset,
     public_dataset,
@@ -476,6 +495,7 @@ def training(
     ]
 
     options = dict(
+        max_price=max_price,
         data=dict(datasets=datasets),
         environment=dict(
             type="CUSTOM" if custom_image else environment,
@@ -597,11 +617,11 @@ def training(
             "rtx2070s",
             "rtx2080ti",
             "rtx3090",
-            "k80",
             "p100",
             "t4",
             "v100",
             "a100",
+            "a6000",
         ],
         case_sensitive=False,
     ),
@@ -609,6 +629,14 @@ def training(
     show_default=True,
     help="GPU type.",
 )
+@click.option(
+    "--max-price",
+    "-mp",
+    type=click.FLOAT,
+    default=10.0,
+    show_default=True,
+    help="Max Price (per GPU).",
+)
 @click.option(
     "--input-dir",
     type=click.Path(exists=True, file_okay=False, resolve_path=True),
@@ -734,6 +762,7 @@ def inference(
     disk_size,
     gpu_count,
     gpu_type,
+    max_price,
     input_dir,
     input_type,
     input_uri,
@@ -758,6 +787,7 @@ def inference(
     """
 
     options = dict(
+        max_price=max_price,
         data=dict(datasets=[]),
         environment=dict(
             type="CUSTOM" if custom_image else environment,
@@ -905,11 +935,11 @@ def from_json(config, attach, connect, file):
             "rtx2070s",
             "rtx2080ti",
             "rtx3090",
-            "k80",
             "p100",
             "t4",
             "v100",
             "a100",
+            "a6000",
         ],
         case_sensitive=False,
     ),
@@ -917,6 +947,14 @@ def from_json(config, attach, connect, file):
     show_default=True,
     help="GPU type.",
 )
+@click.option(
+    "--max-price",
+    "-mp",
+    type=click.FLOAT,
+    default=10.0,
+    show_default=True,
+    help="Max Price (per GPU).",
+)
 @click.option(
     "--environment",
     type=click.Choice(
@@ -1008,6 +1046,7 @@ def endpoint(
     disk_size,
     gpu_count,
     gpu_type,
+    max_price,
     environment,
     custom_image,
     env,
@@ -1027,6 +1066,7 @@ def endpoint(
     routes = [json.loads(item) for item in route]
 
     options = dict(
+        max_price=max_price,
         environment=dict(
             type="CUSTOM" if custom_image else environment,
             custom_image=custom_image,
